@@ -37,6 +37,7 @@ osmo-build-dep.sh libgtpnl
 build_from_netfilter() {
 ###  TODO: enable osmo-build-dep.sh to build from git.netfilter.org URL?
 	project="$1"
+	cfg="$2"
 	set +x
 	echo
 	echo
@@ -47,19 +48,20 @@ build_from_netfilter() {
 	if [ -d "./$project" ]; then
 		rm -rf "./$project"
 	fi
-	git clone "git://git.netfilter.org/$project" "$project"
+	git clone "https://git.netfilter.org/$project" "$project"
 	cd "$project"
 	autoreconf --install --force
 	./configure \
 		--prefix="$inst/stow/$project" \
 		--without-cli \
 		--disable-man-doc \
-		--enable-python=no
+		--enable-python=no \
+		$cfg
 	$MAKE $PARALLEL_MAKE install
 	STOW_DIR="$inst/stow" stow --restow $project
 }
 build_from_netfilter libnftnl
-build_from_netfilter nftables
+build_from_netfilter nftables "--with-unitdir=$inst/stow/$project/lib/systemd/system"
 
 # Additional configure options and depends
 CONFIG=""
